@@ -5,6 +5,7 @@ main entry point to the program
 import os
 import subprocess
 import glob
+import sys
 
 import pylogconf.core
 from pytconf import register_main, config_arg_parse_and_launch, register_endpoint
@@ -72,7 +73,7 @@ def repos_list_private() -> None:
 
 
 @register_endpoint(
-    description="Cleanup old failing or un-needed runs",
+    description="Cleanup old failing or un-needed runs in all workflows in all repositories",
     configs=[
         ConfigGithub,
         ConfigOutput,
@@ -103,7 +104,7 @@ def runs_cleanup() -> None:
 
 
 @register_endpoint(
-    description="Show workflow runs",
+    description="Show all runs in all workflows in all repos",
     configs=[
         ConfigGithub,
     ],
@@ -117,7 +118,7 @@ def runs_show() -> None:
 
 
 @register_endpoint(
-    description="Show workflow currently running",
+    description="Show all running runs in all workflows in all repositories",
     configs=[
         ConfigGithub,
     ],
@@ -132,7 +133,7 @@ def runs_show_running() -> None:
 
 
 @register_endpoint(
-    description="Show failing workflow last run",
+    description="Show all runs which are last and failing in all workflows and all repositories",
     configs=[
         ConfigGithub,
     ],
@@ -206,6 +207,23 @@ def pull_all() -> None:
                 print(f"skipping non-github project [{project}]")
 
 
+@register_endpoint(
+    description="Run all workflows",
+    configs=[
+        ConfigGithub,
+        ConfigOutput,
+    ],
+)
+def workflows_run() -> None:
+    g = github.Github(login_or_token=ConfigGithub.token)
+    for repo in g.get_user(ConfigGithub.username).get_repos():
+        for workflow in repo.get_workflows():
+            print(f"{repo.name}: {workflow.name}...", end='')
+            sys.stdout.flush()
+            ret = workflow.create_dispatch(ref="master")
+            print(f"f{ret}")
+
+
 @register_main(
     main_description="pygitpub will help you work with github",
     app_name="pygitpub",
